#!/bin/bash
# $Id: rwx_test.sh 5 2007-07-27 12:44:16Z pkun $

echo `gettext "# Testing correct  Acl RWX mechanism"`

# Global test result (default = 0 : ok)
export GLOBALRES=0

export TMPFILE="/tmp/mactests_file"
export RESFILE="/tmp/mactests_res"

VERBOSE=
while getopts v OPTION
do
case $OPTION in
    v) VERBOSE=yes ;;
esac
done


# Prepare testing environment
groupadd mactests_users
useradd -d /tmp mactests_owner
useradd -d /tmp -G mactests_users mactests_user1
useradd -d /tmp mactests_other


echo >$TMPFILE
chown mactests_owner:mactests_users $TMPFILE
chmod 600 $TMPFILE
echo >$RESFILE
chmod 666 $RESFILE

# Subtest 1
echo -n `gettext "Set Acl for owner... "` 1>&2
setfacl -m user::r $TMPFILE
echo -n `gettext "check bitmask... "` 1>&2
log=`ls -l $TMPFILE | grep "^-r--"`
if [  "$log" == "" ]; then
    echo `gettext "Incorrect work of acl system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi


echo -n `gettext "Set bitmask for owner... "` 1>&2
chmod 600 $TMPFILE
echo -n `gettext "check Acl... "` 1>&2
log=`getfacl $TMPFILE 2>/dev/null | grep "^user::rw"` 
if [  "$log" == "" ]; then
    echo `gettext "Incorrect work of acl system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi


echo -n `gettext "Set Acl for group... "` 1>&2
setfacl -m group::rwx $TMPFILE
echo -n `gettext "check bitmask... "` 1>&2
log=`ls -l $TMPFILE | grep "^-rw-rwx"`
if [  "$log" == "" ]; then
    echo `gettext "Incorrect work of acl system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi


echo -n `gettext "Set bitmask for group... "` 1>&2
chmod 600 $TMPFILE
echo -n `gettext "check Acl... "` 1>&2
log=`getfacl $TMPFILE 2>/dev/null | grep "^group::---"`
if [  "$log" == "" ]; then
    echo `gettext "Incorrect work of acl system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi


echo -n `gettext "Set Acl for other... "` 1>&2
setfacl -m other::rwx $TMPFILE
echo -n `gettext "check bitmask... "` 1>&2
log=`ls -l $TMPFILE | grep "^-rw----rwx" `
if [  "$log" == "" ]; then
    echo `gettext "Incorrect work of acl system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi

echo -n `gettext "Set bitmask for other... "` 1>&2
chmod 600 $TMPFILE
echo -n `gettext "check Acl... "` 1>&2
log=`getfacl $TMPFILE 2>/dev/null | grep "^other::---"`
if [  "$log" == "" ]; then
    echo `gettext "Incorrect work of acl system"` 1>&2
    echo `gettext "FAIL"` 1>&2
    GLOBALRES=1	
else
	if [ $VERBOSE ]; then 
	    echo -n `gettext "found: "`
	    echo  $log
	fi
	echo `gettext "PASS"` 1>&2
fi







# Remove testing environment
rm -f $TMPFILE $RESFILE
export TMPFILE
export RESFILE

userdel mactests_owner
userdel mactests_user1
userdel mactests_other
groupdel mactests_users

exit $GLOBALRES
