import subprocess
import re
import os


class AuditError(Exception):
    def __init__(self, *args):
        if args:
            self.message = args[0]
        else:
            self.message = None

    def __str__(self):
        if self.message:
            return 'AuditError: {} '.format(self.message)
        else:
            return 'AuditError has been raised.'


def read_audit(start, end):
    auparam = ' -i'
    cmd = 'ausearch -ts ' + start.strftime('%H:%M:%S') + ' -te ' + end.strftime('%H:%M:%S') + auparam
    p = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)
    out, err = p.communicate()
    if p.returncode:
        raise AuditError("Can't get audit messages.")
    return out.decode()


def next_event(t):
    for s in t.split('----\n'):
        if s:
            yield s


def next_msg(t):
    for s in t.splitlines():
        yield dict(re.findall(r'(\S+)\s*=\s*(.*?)\s*(?=\S+\s*=|$)', s))


def check_event(check, event):
    i = 0
    for msg in next_msg(event):
        for fld in check[i]:
            if fld not in msg or check[i][fld] not in msg[fld]:
                break
        else:
            i += 1
            if i == len(check):
                return True
    return False


def assert_audit_enabled():
    parsecfs_flags = [
        '/parsecfs/disable-all-audit',
        '/parsecfs/disable-non-mac-audit',
        '/parsecfs/disable-denied-audit',
    ]
    for fn in parsecfs_flags:
        with open(fn) as f:
            if f.read(1) != '0':
                raise AuditError(fn + ' is not 0')


def disable_audit_rules(verbose=True):
    rc = subprocess.call(
        'auditctl -D -k parsec-tests', shell=True,
        stderr=None if verbose else subprocess.DEVNULL)
    if rc and verbose:
        raise AuditError("Can't stop audit system.")


def enable_audit_rules():
    rules = []
    for rules_dir in ['/etc/audit/rules.d', '/usr/lib/parsec/audit/rules.d']:
        for fn in [os.path.join(rules_dir, f) for f in next(os.walk(rules_dir), (None, None, []))[2] if f.startswith('10-parsec')]:
            with open(fn) as f:
                for rule in f:
                    i = rule.rfind('-k parsec')
                    if i < 0:
                        continue
                    rule = rule[:i]
                    if rule in rules:
                        continue
                    rules.append(rule)
                    rc = subprocess.call(
                        'auditctl ' + rule + '-k parsec-tests', shell=True, stderr=None)
                    if rc:
                        raise AuditError("Can't start audit system.")
