#!/bin/bash
# $Id: rwx_test.sh 5 2007-07-27 12:44:16Z pkun $

echo `gettext "# Testing the file system RWX mechanism"`

# Global test result (default = 0 : ok)
export GLOBALRES=0

export TMPFILE="/tmp/mactests_file"
export RESFILE="/tmp/mactests_res"

# Prepare testing environment
groupadd mactests_users
useradd -s /bin/false -d /tmp mactests_owner
useradd -s /bin/false -d /tmp -G mactests_users mactests_user1
useradd -s /bin/false -d /tmp mactests_other

function cleanup() {
    # Remove testing environment
    rm -f $TMPFILE $RESFILE
    export TMPFILE
    export RESFILE

    userdel mactests_owner
    userdel mactests_user1
    userdel mactests_other
    groupdel mactests_users
}

trap cleanup EXIT

addgroup mactests_owner astra-admin
addgroup mactests_other astra-admin
addgroup mactests_user1 astra-admin

echo >$TMPFILE
chown mactests_owner:mactests_users $TMPFILE
chmod 640 $TMPFILE
echo >$RESFILE
chmod 666 $RESFILE

# Subtest 1
echo -n `gettext "The file read testing for owner..."` 1>&2
su -s /bin/sh -c 'cat $TMPFILE >/dev/null 2>&1; echo $? > $RESFILE' mactests_owner 2>/dev/null 
declare -i RES=`cat $RESFILE`
if [ ! $RES -eq 0 ]; then
    echo `gettext "FAIL"` 1>&2
    echo `gettext "The non-restricted reading denied "`$TMPFILE1 1>&2
    GLOBALRES=1
else
    echo `gettext "PASS"` 1>&2
fi

# Subtest 2
echo -n `gettext "The file write testing for owner..."` 1>&2
su -s /bin/sh -c 'echo test 2>/dev/null >> $TMPFILE; echo $? > $RESFILE' mactests_owner 2>/dev/null
declare -i RES=`cat $RESFILE`
if [ ! $RES -eq 0 ]; then
    echo `gettext "FAIL"` 1>&2
    echo `gettext "The non-restricted writing denied "`$TMPFILE1 1>&2
    GLOBALRES=1
else
	echo `gettext "PASS"` 1>&2
fi

# Subtest 3
echo -n `gettext "The file read testing for group-owner..."` 1>&2
su -c 'cat $TMPFILE >/dev/null 2>&1; echo $? > $RESFILE' mactests_user1 2>/dev/null
declare -i RES=`cat $RESFILE`
if [ ! $RES -eq 0 ]; then
    echo `gettext "FAIL"` 1>&2
    echo `gettext "The non-restricted reading denied "`$TMPFILE1 1>&2
    GLOBALRES=1
else
    echo `gettext "PASS"` 1>&2
fi

# Subtest 4
echo -n `gettext "The file write testing for group-owner..."` 1>&2
su -s /bin/sh -c 'echo test 2>/dev/null >> $TMPFILE; echo $? > $RESFILE' mactests_user1 2>/dev/null
declare -i RES=`cat $RESFILE`
if [ $RES -eq 0 ]; then
    echo `gettext "FAIL"` 1>&2
    echo `gettext "The restricted writing granted "`$TMPFILE1 1>&2
    GLOBALRES=1
else
    echo `gettext "PASS"` 1>&2
fi

# Subtest 5
echo -n `gettext "The file read testing for other..."` 1>&2
su -s /bin/sh -c 'cat $TMPFILE >/dev/null 2>&1; echo $? > $RESFILE' mactests_other 2>/dev/null
declare -i RES=`cat $RESFILE`
if [ $RES -eq 0 ]; then
    echo `gettext "FAIL"` 1>&2
    echo `gettext "The restricted reading granted "`$TMPFILE1 1>&2
    GLOBALRES=1
else
    echo `gettext "PASS"` 1>&2
fi

# Subtest 6
echo -n `gettext "The file write testing for other..."` 1>&2
su -s /bin/sh -c 'echo test 2>/dev/null >> $TMPFILE; echo $? > $RESFILE' mactests_other 2>/dev/null
declare -i RES=`cat $RESFILE`
if [ $RES -eq 0 ]; then
    echo `gettext "FAIL"` 1>&2
    echo `gettext "The restricted writing granted "`$TMPFILE1 1>&2
    GLOBALRES=1
else
    echo `gettext "PASS"` 1>&2
fi

cleanup

exit $GLOBALRES
