#!/bin/bash
# $Id: secdel_test.sh 5 2007-07-27 12:44:16Z pkun $

# Global test result (default = 0 : ok)
export GLOBALRES=0

IMAGE="/tmp/image-$$"
MNTPOINT="/tmp/mntpoint-$$"

execute()
{
  #if [ "x$FSTYPE" == "x" ];then
  #	echo "ERROR! Need file system type. For example: ./sec_del.sh ext3"
  #	exit 1
  #fi

  FSTYPE=$1
  SECDELTYPE=$2

  if [ "$FSTYPE" == "ext3" -o "FSTYPE" == "ext4" ];then
    MKFSOPT="-j"
  else
    MKFSOPT=""
  fi

  echo `gettext "# Testing clean on FS "`$FSTYPE`gettext " and option "`$SECDELTYPE

  # Subtest 1
  echo -n `gettext "Disk image creation..."` 1>&2
  dd if=/dev/zero of=$IMAGE bs=32M count=1 >/dev/null 2>&1
  if [ ! "$?" -eq 0 ]; then
      echo `gettext "Error while image file creation\n"` 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  fi

  case $FSTYPE in
    ext2)	echo "y" | mke2fs -t ext2 $MKFSOPT $IMAGE >/dev/null 2>&1
      ;;
    ext3)	echo "y" | mke2fs -t ext3 $MKFSOPT $IMAGE >/dev/null 2>&1
      ;;
    ext4)	echo "y" | mke2fs -t ext4 $MKFSOPT $IMAGE >/dev/null 2>&1
      ;;
    xfs)	mkfs.xfs -i attr=2 -n size=16384 -f $IMAGE >/dev/null 2>&1
      ;;
    *)	echo `gettext "Unknown file system:"`" $FSTYPE" 1>&2
  esac

  if [ ! "$?" -eq 0 ]
  then 
      echo `gettext "Error while file system creation\n"` 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  fi

  mkdir $MNTPOINT >/dev/null 2>&1
  if [ ! "$?" -eq 0 ]
  then 
      echo `gettext "Error while directory creation"`" $MNTPOINT\n" 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  else
      echo `gettext "PASS"` 1>&2
  fi

  # Subtest 2
  echo -n `gettext "File creation within file-system..."` 1>&2
  mount -t $FSTYPE -o loop,$SECDELTYPE,sync $IMAGE $MNTPOINT >/dev/null
  if [ ! "$?" -eq 0 ]
  then 
      echo `gettext "Error mounting"`" $IMAGE -> $MNTPOINT\n" 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  fi
  echo "Hello world!" > $MNTPOINT/file.txt 
  if [ ! "$?" -eq 0 ]
  then 
      echo `gettext "Error creating text file\n"` 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  else
      echo `gettext "PASS"` 1>&2
  fi

  # Subtest 3
  echo -n `gettext "Testing file's content existing..."` 1>&2
  umount $MNTPOINT >/dev/null 2>&1
  if [ ! "$?" -eq 0 ]; then 
      echo `gettext "Error unmounting\n"` 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  fi
  fgrep "Hello world!" $IMAGE >/dev/null 2>&1
  if [ ! "$?" -eq 0 ]; then 
      echo `gettext "Can't find signature"` 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  else
      echo `gettext "PASS"` 1>&2
  fi

  # Subtest 3.5
  echo -n `gettext "SECDEL file deleting and searching for file's content on disk..."` 1>&2
  mount -t $FSTYPE -o loop,$SECDELTYPE,sync $IMAGE $MNTPOINT >/dev/null 2>&1
  if [ ! "$?" -eq 0 ]
  then 
      echo `gettext "Error mounting"`" $IMAGE -> $MNTPOINT.\n" 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  fi
  #chattr +s $MNTPOINT/file.txt
  rm -f $MNTPOINT/file.txt >/dev/null 2>&1
  umount $MNTPOINT >/dev/null 2>&1

  fgrep "Hello world!" $IMAGE
  if [ "$?" -eq 0 ]
  then 
      echo `gettext "Signature has been found"` 1>&2
      echo `gettext "FAIL"` 1>&2
      GLOBALRES=1
  else
      echo `gettext "PASS"` 1>&2
  fi
  echo -e "\n\n"

  # Destruction
  rm -f $IMAGE >/dev/null 2>&1
  rmdir $MNTPOINT >/dev/null 2>&1
}

for MNTOPT in "secdel" "secdelrnd"
do
	for EXTTYPE in "ext2" "ext3" "ext4" "xfs"
	do
		execute  $EXTTYPE  $MNTOPT
	done
done

exit $GLOBALRES
